@@ -33,6 +33,7 @@
 #include "utils/file.h"
 #include "utils/base64.h"
 #include "utils/nt_pthread.h"
+#include "cloud/nt_cloud.h"
 #include "net/nt_http.h"
 #include "net/nt_cookie.h"
 #include "_2ch/model_2ch.h"
@@ -159,6 +160,7 @@ BOOL nt_read_thread(nt_2ch_selected_item_handle h_select)
 	char	*p_src,	*p_dst;
 	size_t	n_src,	n_dst;
 	BOOL is_matchi_bbs;
+	nt_cloud_handle h_cloud;
 	
 	assert(h_select);
 	assert(h_select->chk_sum == NT_2CH_SELECTED_ITEM_CHK_SUM);
@@ -288,6 +290,13 @@ BOOL nt_read_thread(nt_2ch_selected_item_handle h_select)
 	fclose(fp_src);
 	iconv_close(icd);
 	free(outp);
+	h_cloud = nt_cloud_get_handle();
+	if(h_cloud && threadp->num_res > 0){
+		nt_cloud_update_read_count_async(h_cloud,
+				boardp->name, file_name, threadp->num_res);
+	}
+	if(h_cloud)
+		nt_cloud_release_ref(h_cloud);
 	return (threadp->num_res > 0);
 }
 
