@@ -57,6 +57,8 @@ char *NCE_AUTH_URL;
 char *NCE_ID;
 char *NCE_PASS;
 
+char CA_FILE_PATH[1024];
+
 static char *app_name = PACKAGE_NAME;
 static char *version_name = PACKAGE_VERSION;
 static char *def_editor_cmd = "vi";
@@ -69,7 +71,9 @@ struct option longopts[] = {
 	{"version", 0, NULL, 'v'},
 	{"help", 0, NULL, 'h'},
 	{"editor", 1, NULL, 'e'},
-	{"out-path", 1, NULL, 'o'}
+	{"out-path", 1, NULL, 'o'},
+	{"pem", 1, NULL, 'p'},
+	{NULL, 0, NULL, 0}
 };
 
 extern void print_help();
@@ -101,6 +105,7 @@ int set_option(int argc, char* argv[])
 	NCE_AUTH_URL = NULL;
 	NCE_ID = NULL;
 	NCE_PASS = NULL;
+	CA_FILE_PATH[0] = '\0';
 	
 	NT_MAINLOOP_POLLING_INTERVAL = 100;
 	NT_PTHREAD_POOL_SIZE = 5;
@@ -137,7 +142,7 @@ int set_option(int argc, char* argv[])
 	}
 
 	while((opt = getopt_long(
-			argc, argv, "hvro:", longopts, NULL)) != -1){
+			argc, argv, "hvro:p:", longopts, NULL)) != -1){
 
 		switch(opt){
 		case 'r':
@@ -154,7 +159,7 @@ int set_option(int argc, char* argv[])
 		case 'o':
 			printf("output path: %s\n", optarg);
 			len = strlen(optarg);
-			if(len == 0)
+			if(len == 0 || len > sizeof(LOG_PATH)-5)
 				break;
 			strcpy(LOG_PATH, optarg);
 			if(LOG_PATH[len-1] != '/'){
@@ -162,10 +167,21 @@ int set_option(int argc, char* argv[])
 			}
 			strcpy(LOG_PATH+len, "log");
 			break;
+		case 'p':
+			printf("ca file path: %s\n", optarg);
+			len = strlen(optarg);
+			if(len == 0 || len > sizeof(CA_FILE_PATH)-1)
+				break;
+			strcpy(CA_FILE_PATH, optarg);
+			break;
 		default:
 			break;
 		}
 	}
+	
+	if(CA_FILE_PATH[0] == '\0'){
+		strcpy(CA_FILE_PATH, "cacert.pem");
+	}
 	/*for(; optind < argc; optind++){
 		fprintf(stderr, "Unrecognized argument %s\n",
 					argv[optind]);
@@ -187,6 +203,8 @@ extern BOOL read_resource(const char *path)
 		return FALSE;
 	
 	while(fgets(buf, sizeof(buf), fp)){
+		if(buf[0] == '#')
+			continue;
 		cptr = strchr(buf, '=');
 		if(!cptr)
 			continue;
