@@ -17,7 +17,15 @@
 */
 #ifndef _DISP_H_
 #define _DISP_H_
+
+#ifdef HAVE_NCURSESW_NCURSES_H
+#include <ncursesw/ncurses.h>
+#else
+#include <ncurses.h>
+#endif
+
 #include "ui/disp_win.h"
+#include "_2ch/model_2ch.h"
 #include "_2ch/search_2ch.h"
 #include "usr/favorite_t.h"
 #include "usr/usr_db_t.h"
@@ -48,6 +56,9 @@
 #define DISP_CMD_SEL_FAVORITE_THREAD (6*256)
 #define DISP_CMD_UPDATE_FAVORITE (7*256)
 #define DISP_CMD_AUTO_SCROLL (8*256)
+#define DISP_CMD_UPLOAD_ALL (9*256)
+#define DISP_CMD_UPLOAD_BOARDS (10*256)
+#define DISP_CMD_UPLOAD_THREADS (11*256)
 
 extern int disp_board_menu(nt_window_tp wp, 
 		nt_2ch_model_handle h_model, nt_2ch_selected_item_handle h_select);
