@@ -176,6 +176,8 @@ int main(int argc, char *argv[])
 #ifdef NT_CLOUD
 	if(h_cloud){
 		text_linkp = nt_cloud_download_file(h_cloud, "ft.txt");
+		nt_cloud_query_favorite_attributes_async(h_cloud, usr_db_handle);
+		//nt_cloud_query_attributes(h_cloud, usr_db_handle, 0);
 	}
 #endif
 	if(!text_linkp)
@@ -448,13 +450,20 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					}
 					ch = NT_KEY_NONE;
 					status_msg = NT_INFO_REFRESH_BOARD_SUCCESS;
+					state = DISP_STATE_THREADTITLE;
+					disp_state = state;
 					continue;
 				}else{
 					status_msg = NT_ERR_MSG_COUDLNOT_READ_BOARD;
 				}
 				state = DISP_STATE_THREADTITLE;
 			}else if(DISP_STATE_RESLIST == state){
+				disp_state = state;
 				if(!nt_read_thread(h_sel_items)){
+					if(!rwinp->data){
+						state = DISP_STATE_THREADTITLE;
+						disp_state = state;
+					}
 					wclear(scrp);
 					ch = NT_KEY_NONE;
 					continue;
@@ -466,7 +475,6 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 					free_reslist_ctx(rwinp->data);
 					rwinp->data = NULL;
 				}
-				disp_state = state;
 				state = DISP_STATE_THREADTITLE;
 				ch = NT_KEY_NONE;
 				continue;
@@ -795,6 +803,9 @@ static BOOL DoLoop(WINDOW *scrp, nt_usr_db_handle db_handle,
 				if(async_data.code == NT_PTHREAD_RESULT_UPDATE_BOARD){
 					ch = NT_KEY_CMD_BOARD_UPDATE;
 					//fprintf(stderr, "Async result recieved.!\n");
+				}else if(async_data.code == NT_PTHREAD_RESULT_UPDATE_FAVORITE){
+					ch = NT_KEY_CMD_FAVORITE_UPDATE;
+					//fprintf(stderr, "Async result recieved.!\n");
 				}else{
 					h_timer = nt_timer_ring_a_bell();
 					if(h_timer){
