@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <assert.h>
 
+#include "env.h"
 #include "utils/nt_std_t.h"
 #include "utils/text.h"
 #include "utils/zip.h"
@@ -138,7 +139,7 @@ int nt_http_post2(const char *url, const char *post_data,
 	if(IS_SET_FLAG(headerp,SSL_FLAG)){
 		data_len = strlen(data);
 		sprintf(ssl_connect, "%s:443", headerp->host);
-		if(!nt_ssl_connect(ssl_connect, "cacert.pem", FALSE,
+		if(!nt_ssl_connect(ssl_connect, CA_FILE_PATH, FALSE,
 					data, &data_len, sizeof(data))){
 			nt_http_free_header(headerp);
 			return result;
@@ -224,7 +225,7 @@ int nt_http_post2(const char *url, const char *post_data,
 				result = 0;
 			}else if(IS_SET_FLAG(responsep, CHUNKED_FLAG)){
 				p3 = p1 = out_buf;
-				while(0 < (nread = strtol(p1, &p2, 10))){
+				while(0 < (nread = strtol(p1, &p2, 16))){
 					memcpy(p3, p2+2, nread);
 					p3 += nread;
 					p1 = p2 + nread + 4;
@@ -316,7 +317,7 @@ BOOL nt_http_get(const char *url, const char *out_path,
 	if(IS_SET_FLAG(headerp,SSL_FLAG)){
 		data_len = strlen(data);
 		sprintf(ssl_connect, "%s:443", headerp->host);
-		if(!nt_ssl_connect(ssl_connect, "cacert.pem", FALSE,
+		if(!nt_ssl_connect(ssl_connect, CA_FILE_PATH, FALSE,
 					data, &data_len, sizeof(data))){
 			nt_http_free_header(headerp);
 			return FALSE;
