@@ -99,9 +99,14 @@ int disp_favorite(nt_window_tp wp,
 	}
 	
 	switch(wp->key){
+	case NT_KEY_CMD_FAVORITE_UPDATE:
+		if(!nt_favorite_set_read_count(h_favorite, h_usr_db)){
+			fputs("Couldn't open user_db handle", stderr);
+		}
+		break;
 	case NT_KEY_CMD_BOARD_UPDATE:
 		if(!nt_favorite_set_num_res(h_model, h_favorite)){
-			fputs("Couldn't open user_db handle", stderr);
+			fputs("Couldn't set res count into favorite thread", stderr);
 		}
 		break;
 	case NT_KEY_REFRESH:
