@@ -234,6 +234,7 @@ int disp_reslist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle h_
 
 	switch(ch){
 	case NT_KEY_CMD_BOARD_UPDATE:
+	case NT_KEY_CMD_FAVORITE_UPDATE:
 		if(auto_scroll_state != AUTO_SCROLL_NONE){
 			result_state |= DISP_CMD_AUTO_SCROLL;
 			ctxp->auto_scroll = auto_scroll_state;
@@ -972,7 +973,7 @@ static ctx_reslist_tp init_context(nt_2ch_selected_item_handle h_select,
 	ctxp->prev_read_cnt = 
 		nt_usr_db_update_read_count(usr_db_handle, 
 				board_name, dat_name,
-				ctxp->res_num);
+				ctxp->res_num,  NULL);
 	if(ctxp->prev_read_cnt < 0)
 		ctxp->prev_read_cnt = 0;
 	if(ctxp->prev_read_cnt > 0){
