@@ -20,7 +20,6 @@
 #include <string.h>
 #include <assert.h>
 #include <wchar.h>
-#include <ncursesw/ncurses.h>
 #include <regex.h>
 
 #include "env.h"
@@ -34,6 +33,7 @@
 #include "utils/text.h"
 #include "ui/disp.h"
 #include "ui/disp_string.h"
+#include "cloud/nt_cloud.h"
 
 typedef struct tag_ctx_threadlist_t *ctx_threadlist_tp;
 typedef struct tag_ctx_threadlist_t
@@ -132,6 +132,8 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 	const char *start, *end;
 	char *cptr;
 	int result_state;
+	nt_cloud_handle h_cloud;
+	BOOL b_ret;
 
 	result_state = DISP_STATE_THREADTITLE;
 	sort = FALSE;
@@ -152,6 +154,14 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 	board_name = nt_board_get_name(h_board);
 
 	if(!ctxp->thread_data_list){
+		h_cloud = nt_cloud_get_handle();
+		if(h_cloud){
+			if(nt_cloud_query_board_attributes(h_cloud,
+					board_name, db_handle, 0)){
+				
+			}
+			nt_cloud_release_ref(h_cloud);
+		}
 		ctxp->thread_data_list =
 			nt_usr_db_query_read_count_list(
 					db_handle, board_name);
@@ -255,6 +265,15 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 					if(!nt_usr_db_delete_board_log(db_handle,
 							board_name))
 						break;
+					h_cloud = nt_cloud_get_handle();
+					if(h_cloud){
+						if(!nt_cloud_delete_read_count(h_cloud,
+								board_name, NULL, 0)){
+							nt_cloud_release_ref(h_cloud);
+							break;
+						}
+						nt_cloud_release_ref(h_cloud);
+					}
 					result_state = DISP_STATE_REFRESH;
 					goto ERROR_TRAP;
 				}
@@ -264,6 +283,7 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 					break;
 				clistp = linkp;
 				num = -1;
+				h_cloud = nt_cloud_get_handle();
 				do{
 					threadp = get_thread_by_seq_no(
 						ctxp->thread_disp_list, linkp->n_data);
@@ -271,14 +291,20 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 						break;
 						
 					if(linkp->n_data != num){
-						nt_usr_db_delete_thread_log(db_handle,
+						b_ret = nt_usr_db_delete_thread_log(db_handle,
 								board_name, 
 								threadp->dat_name,
 								&ctxp->thread_data_list);
+						if(b_ret && h_cloud){
+							(void)nt_cloud_delete_read_count(h_cloud,
+									board_name, threadp->dat_name, 0);
+						}
 						num = linkp->n_data;
 					}
 					linkp = linkp->next;
 				}while(clistp != linkp);
+				if(h_cloud)
+					nt_cloud_release_ref(h_cloud);
 				nt_all_link_free(linkp, NULL);
 				result_state = DISP_STATE_REFRESH;
 				goto ERROR_TRAP;
@@ -458,7 +484,7 @@ int disp_threadlist(nt_window_tp wp, int prev_state, nt_2ch_selected_item_handle
 				}
 			}else{
 				if(-1 < swprintf(
-					buf, sizeof(buf)-1, L"(%d) 未読:%d ", 
+					buf, sizeof(buf)/sizeof(wchar_t)-1, L"(%d) 未読:%d ", 
 						threadp->num_res, 
 						threadp->num_res - read_count)){
 				}
