@@ -1166,7 +1166,8 @@ BOOL nt_favorite_set_read_count(nt_favorite_handle h_favorite, nt_usr_db_handle
 				read_count = nt_usr_db_get_read_count_by_dat_name(
     					linkp, dat_name);
     			if(read_count == -1)
-    				continue;
+    				read_count = 0;
+    				//continue;
     			
     			nt_favorite_thread_set_read_count(h_thread, read_count);
 			}
